@@ -9,16 +9,14 @@ from subprocess import call
 
 
 def ffconcat(cats, tvp, trial_type):
-    # cats is a list of strings ["cat--id"]
-    # tvp: /path/to/trials/videos/
-    # trial_type: either "cat_alone" or "owner"
-
-    if tvp.endswith('/') is False:
-
-        raise ValueError('Path does not end with a trailing slash "/"')
+    """
+    cats is a list of strings ["cat--id"]
+    tvp: /path/to/trials/videos/
+    trial_type: either "cat_alone" or "owner"
+    """
 
     for cat in cats:
-        tc = tvp + cat
+        tc = f'{tvp}/{cat}'
         if trial_type == "cat_alone":
             vid_list = [
                 tc + '_T2.mp4', tc + '_T4.mp4', tc + '_T6.mp4', tc + '_T8.mp4',
@@ -33,7 +31,7 @@ def ffconcat(cats, tvp, trial_type):
 
         else:
             raise ValueError(
-                'False trial type!  The trial type should be either "cat_alone" or "with_owner".'
+                'False trial type!  Option is either "cat_alone" or "with_owner".'
             )
 
         cat_txt = f'{cat}.txt'
@@ -57,11 +55,11 @@ def ffconcat(cats, tvp, trial_type):
 
         if trial_type == "cat_alone":
 
-            ffmpeg_command = f'#!/bin/bash\n ffmpeg -f concat -safe 0 -i {cat}.txt -c copy -y {tvp}{cat}_cat.mp4'
+            ffmpeg_command = f'#!/bin/bash\n ffmpeg -f concat -safe 0 -i {cat}.txt -c copy -y {tvp}/{cat}_cat.mp4'
 
         elif trial_type == "with_owner":
 
-            ffmpeg_command = f'#!/bin/bash\n ffmpeg -f concat -safe 0 -i {cat}.txt -c copy -y {tvp}{cat}_owner.mp4'
+            ffmpeg_command = f'#!/bin/bash\n ffmpeg -f concat -safe 0 -i {cat}.txt -c copy -y {tvp}/{cat}_owner.mp4'
 
         file_sh.write(ffmpeg_command)
         file_sh.close()
