@@ -13,16 +13,23 @@ from rich.console import Console
 from pathlib import Path
 from glob import glob
 from toxopy import trials
+from dirtyR import smooth
 from shutil import move
+from subprocess import Popen
+from platform import platform
 
 
-def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
+def improve_dlc_output(inDIR, outDIR, only_improve_csv=False):
+    """
+    inDIR is the directory with the original csv files
+    outDIR is the output directory
+    """
 
     console = Console()
     trls = trials()
 
     def gg(i):
-        return sorted(glob(input_dir + f'/*_{i}.csv'))
+        return sorted(glob(inDIR + f'/*_{i}.csv'))
 
     chwo, oh, ch = gg('chwo'), gg('oh'), gg('ch')
 
@@ -36,11 +43,11 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
             """Add time and trial type."""
 
             df = pd.read_csv(csv_file)
+
             df = df.iloc[2:, :3]
 
             if trial_type == 'owner':
                 time = 1020
-
             elif trial_type == 'cat':
                 time = 600
 
@@ -73,16 +80,14 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
                                 tls.append(p)
 
             df['time'], df['trial'] = time, tls
+
             df.columns = ['indx', 'x', 'y', 'time', 'trial']
 
-            df.to_csv(file_name,
-                      index=False,
-                      sep=',',
-                      encoding='utf-8')
+            df.to_csv(file_name, index=False, encoding='utf-8')
 
         for i, j in zip([cat_head, owner_hand, cat_alone],
                         ['owner', 'owner', 'cat']):
-            file_name = f'{output_dir}/{Path(i).stem}_improved.csv'
+            file_name = f'{outDIR}/{Path(i).stem}_improved.csv'
             improve_dlc_csv(
                 i, trial_type=j, file_name=file_name)
 
@@ -92,11 +97,12 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
         """Calculate the distance between cat and owner."""
 
         def dt(file_name):
-            improved = f'{output_dir}/{Path(file_name).stem}_improved.csv'
+            improved = f'{outDIR}/{Path(file_name).stem}_improved.csv'
             improved = pd.read_csv(improved, sep=",")
             return pd.DataFrame(improved, columns=improved.columns)
 
         df_cat, df_owner, df_CA = dt(cat_head), dt(owner_hand), dt(cat_alone)
+
         df_CA.rename(columns={'x': 'x_cat', 'y': 'y_cat'}, inplace=True)
 
         tls = df_CA['trial']
@@ -143,6 +149,7 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
 
             if name == 'WO':
                 console.print("\nW/ OWNER TRIALS", style="bold blue")
+
             elif name == 'CA':
                 console.print("\nCAT ALONE TRIALS", style="bold blue")
 
@@ -239,11 +246,12 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
                 acc.append(float(calculateAcc(vi, vf, ti, tf)))
 
             fdf['acceleration'] = acc
-            """Clean zero values in relevant data,
-            then append data to one csv file."""
+
+            """Clean data."""
 
             if name == 'WO':
                 df = pd.concat([result, fdf], axis=1)
+
             elif name == 'CA':
                 df = pd.concat([df_CA, tls, fdf], axis=1)
 
@@ -261,22 +269,139 @@ def improve_dlc_output(input_dir, output_dir, only_improve_csv=False):
 
             df = df.dropna()
 
-            df.to_csv(f'{output_dir}/{cat}_{name}_improved.csv',
+            df.to_csv(f'{outDIR}/{cat}_{name}_improved.csv',
                       index=False,
-                      sep=',',
                       encoding='utf-8')
 
-            console.print("\nDONE!\n", style="bold green")
+            console.print(f"\n{cat.upper()} IS DONE!\n", style="bold blue")
 
         for i in ['ch', 'oh', 'chwo']:
-            tbrm = glob(f'{output_dir}/*_{i}_improved.csv')
+            tbrm = glob(f'{outDIR}/*_{i}_improved.csv')
             [os.remove(x) for x in tbrm]
 
     for x in ['CA', 'WO']:
-        op = f'{output_dir}/{x}'
+        op = f'{outDIR}/{x}'
+
         if not os.path.exists(op):
             os.makedirs(op)
         else:
             pass
-        for file in glob(f'{output_dir}/*_{x}_*.csv'):
+
+        for file in glob(f'{outDIR}/*_{x}_*.csv'):
             move(file, op)
+
+    ca_dir, wo_dir = f'{outDIR}/CA', f'{outDIR}/WO'
+
+    smooth(ca_dir, wo_dir, outDIR)
+
+    while True:
+
+        if 'Darwin' in platform():
+            p = Popen(['open', f'{outDIR}/smooth.r'])
+            returncode = p.wait()
+        else:
+            pass
+
+        ans = input('Done smoothing? (y) ')
+        if ans.lower() == "y":
+            break
+        else:
+            continue
+
+    for x in ['/*', '/.*']:
+        [os.remove(x)
+         for x in glob(f'{outDIR}/{x}') if os.path.isfile(x) is True]
+
+    def one_cat_one_file(ca_dir, wo_dir, outDIR):
+        """
+        'ca_dir' is the dir with cat_alone_improved csv files
+        'wo_dir' is the dir with with_owner_improved csv files
+        """
+
+        cat_alone, with_owner = glob(
+            ca_dir + '/*.csv'), glob(wo_dir + '/*.csv')
+
+        console.print('\nCONCATENATING FILES...', style='bold blue')
+
+        for f1, f2 in tqdm(zip(sorted(cat_alone), sorted(with_owner))):
+
+            cat1, cat2 = Path(f1).stem[:-12], Path(f2).stem[:-12]
+            files = []
+            if cat1 == cat2:
+                files.append(f1), files.append(f2)
+            else:
+                raise ValueError('Something is wrong!')
+
+            cols = ['time', 'x_cat_loess05', 'y_cat_loess05',
+                    'velocity_loess05', 'acceleration_loess05', 'trial']
+
+            combined_csv = pd.concat(
+                [pd.read_csv(f, usecols=cols) for f in files])
+
+            combined_csv.to_csv(f'{outDIR}/{cat1}.csv',
+                                index=False,
+                                encoding='utf-8-sig')
+
+    one_cat_one_file(ca_dir, wo_dir, outDIR)
+
+    def correct_times(outDIR):
+        """'csv_dir' is the path to the folder containing the combined csv files"""
+
+        files = glob(f'{outDIR}/*.csv')
+
+        trials_times = [300, 420, 600, 720, 900, 1020, 1200, 1320, 1500, 1620]
+        additions = [0, 300, 120, 480, 240, 660, 360, 840, 480, 1020]
+
+        console.print('\nCORRECTING TRIALS TIME...', style='bold blue')
+
+        for file in tqdm(files):
+
+            df = pd.read_csv(file, header=[0])
+
+            cat = Path(file).stem
+
+            for trial, ttime, ad in zip(trls, trials_times, additions):
+
+                time = df.loc[(df['trial'] == trial)]['time']
+
+                diff = max(time) - min(time)
+
+                if trial == trial and diff > ttime:
+                    raise ValueError('Failed!', cat, trial, diff)
+
+                elif trial == trial and diff < ttime:
+
+                    def subdf(variable):
+                        return df[df['trial'] == trial][variable]
+
+                    t, v, a, r, x, y = subdf('time') + ad, subdf(
+                        'velocity_loess05'), subdf('acceleration_loess05'), subdf(
+                            'trial'), subdf('x_cat_loess05'), subdf('y_cat_loess05')
+
+                    fdf = pd.DataFrame([t, v, a, r, x, y]).T
+
+                    fdf.to_csv(f'{outDIR}/{cat}_{trial}.csv',
+                               index=False,
+                               encoding='utf-8-sig')
+
+            fs = glob(f'{outDIR}/{cat}_*.csv')
+
+            ccsv = pd.concat([pd.read_csv(i) for i in fs])
+
+            ccsv = ccsv.sort_values(by=['time'])
+
+            ccsv.to_csv(f'{outDIR}/{cat}.csv',
+                        index=False,
+                        encoding='utf-8-sig')
+
+            [os.remove(i) for i in fs]
+
+    correct_times(outDIR)
+
+    cp = f'{outDIR}/combined'
+    if not os.path.exists(cp):
+        os.makedirs(cp)
+    for fi in glob(f'{outDIR}/*.csv'):
+        move(fi, cp)
+
+    console.print('\nDONE!', style='bold green')
